{% extends template_to_extend %}

{% block extra_head %}
	<meta name="keywords" content="{{ flatpage.seo_description }}" />
	<meta name="description" content="{{ flatpage.seo_keywords }}" />
	{% if use_themes and current_theme %}
		<link rel="stylesheet" media="screen, projection" href="/static/themes/{{ current_theme }}/screen.css" />
	{% endif %}
{% endblock %}
{% block title %}{{ flatpage.title }}{% endblock %}

{% block precontent %}
	{% if slideshow %}
		{% include slideshow.template_name %}
	{% endif %}
	{% if presentation %}
		{% include 'zongo/main.html' %}
	{% endif %}
{% endblock %}
{% block content %}
	{% if layout %}
		{% include layout_path %}
	{% endif %}
	{% if flatpage.content %}{{ flatpage.content|safe }}{% endif %}
	{% if flatpage.html %}{{ flatpage.html|safe }}{% endif %}
	{% if layout %}
		{% include 'alapage/layouts/bottom.html' %}
	{% endif %}
{% endblock %}