{% load staticfiles %}
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>{% block title %}Home{% endblock %}</title>
	<meta http-equiv="X-UA-Compatible" content="IE=edge" />
	<meta name="viewport" content="width=device-width, initial-scale=1.0" />
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	{% block extra_head %}{% endblock %}
</head>

<body>
	<div id="header">
		<h1>Django Alapage</h1>
	</div>
	<div>
		{% include "alapage/themes_menu.html" %}
	</div>
	<div id="content">
		{% block layout_top %}{% endblock %}
		{% block content %}{% endblock %}
		{% block layout_bottom %}{% endblock %}
	</div>
	<div id="footer">
		
	</div>
	<style>
	body {
		margin:0;
		padding:0;
		font-family: Verdana, "Bitstream Vera Sans", "Lucida Grande", sans-serif;
	}
	#header {
		min-height:50px;
		background-color:darkslategray;
		color:white;
		padding:0.2em 1em 0.2em 2em;
	}
	#themes_menu {
		background-color:lightslategray;
		padding:1em;
		text-align:right;
	}
	#themes_menu a, #themes_menu a:visited {
		color:white;
		text-decoration:none;
		padding-right:1em;
	}
	#content {
		min-height:40em;
	}
	#footer {
		min-height:50px;
		background-color:darkslategray;
	}
	</style>
</body>
</html>